#
# spec file for package tuner
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tuner
Version:        1.5.2
Release:        1.1
Summary:        Minimalist radio station player
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/louis77/tuner
Source:         https://github.com/louis77/tuner/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.44
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-player-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libgeoclue-2.0)
BuildRequires:  pkgconfig(libsoup-3.0)
Recommends:     %{name}-lang
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-libav
Recommends:     gstreamer-plugins-ugly

%description
An Internet Radio Station player for elementary OS.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.louis77.tuner GTK AudioVideo Audio Player
%find_lang com.github.louis77.tuner %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
touch $PWD/dir.lst
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license LICENSE
%doc README.md
%{_bindir}/com.github.louis77.tuner
%{_datadir}/applications/com.github.louis77.tuner.desktop
%{_datadir}/glib-2.0/schemas/com.github.louis77.tuner.gschema.xml
%{_datadir}/icons/hicolor/*/*/com.github.louis77.tuner.??g
%{_datadir}/metainfo/com.github.louis77.tuner.appdata.xml

%files lang -f %{name}.lang

%changelog
* Sun Sep  1 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 1.5.2:
  Tuner is back! After more than 2 years of pause, development of Tuner started again.
  In this first maintenance release, the following issues have been fixed:
  * Upgrade to libsoup-3.0
  * Fix issues with endpoints not working
  * Removed geo location services (they never really worked)
  * Increase default size of Window
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.1:
  * Update taglib 1.11 to 1.12
  * Change pause button to stop button, fixes #79
  * Update copyright headers
  * Update monetization info for AppCenter
  * Remove debian packaging files
  * Update Copyright year
  * Add GitHub CI
* Sat Nov 20 2021 Alexei Podvalsky <avvissu@yandex.by>
- Add gstreamer-plugins-libav as recommended dependencies
* Fri Nov  5 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.0:
  * Make station list flexible (1-3 columns)
  * Update version number
  * Add release info to appdata
  * Merge branch 'master' of github.com:louis77/tuner
  * Implement background playback #67
  * Merge pull request #70 from Henryws/master
  * Remove sudo and update pacstall URL
  * Replace theme switch with 3-mode dropdown
  * Move Preferences in separate class
  * Merge pull request #65 from SwampRabbit/master
  * Update README.md
  * Merge pull request #64 from ryonakano/ryonakano/setup-l10n
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.4:
  * l10n: Correctly setup the locales
  * Remove multiple default screenshots, fixes #62
  * Update screenshots, prepare for 1.4.2 release
  * Remove debug noise
  * Merge branch 'master' of github.com:louis77/tuner
  * Merge pull request #61 from krisives/granite-dark-mode
  * Added support for reacting to dark mode changing outside of
    the app.
  * Remove FSF membership badge
  * Change email address (no more FSF)
  * Add Stripe key to appdata for new eOS 6, fixes #58
  * Merge pull request #59 from krisives/flatpak
  * Fixed Flatpak manifest to use current directory.
  * Added Flatpak manifest.
  * Merge pull request #55 from Vistaus/master
  * Use join_paths instead of / for older meson version
  * Prepare for release 1.4.0
  * Implement Auto-play and Window title
  * Persist last volume in gsettings
  * Add libera.chat channel
  * Update README, looking for contributors
  * Fix dark-mode not persisted in gsettings #47
  * Add volume control #43
  * Add codec and bitrate to station box #48
  * Relicense source files under GPL3
  * Localize Country display in StationBox
  * Merge pull request #51 from albanobattistella/patch-2
  * Merge pull request #50 from albanobattistella/patch-1
  * Create FUNDING.yml
  * Update it.po
  * Merge pull request #46 from kousu/configurable-api
  * Update RadioBrowserDirectory.vala
  * Document new environment variable
  * Take API server via an environment variable
  * ...
* Sun Oct 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * Show current track if station supports it
  * Add dutch translation, thanks to @Vistaus
* Thu Aug 27 2020 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
